@@ -21,9 +21,10 @@ enum ProtocolSource {
     COSMIC,
     WESTON,
     CHROMEOS,
-    TREELAND,
+    DEEPIN,
     FROG,
     GAMESCOPE,
+    PHOSH,
 };
 
 struct Protocol {
